local_offset

Function local_offset 

pub(crate) fn local_offset(plan: &LogicalPlan, time_index: &str) -> Millisecond
Recovers the offset serialized only by an immediately underlying normalize node.

This is decode-only recovery for manipulators whose wire messages have no offset field. Follow identity projections (as used by timestamp()), but stop at other nodes or changed time columns to avoid applying an inner selector’s offset again to an outer subquery.